Improve this doc

# Error: $location:isrcharg
Wrong $location.search() argument type

    The first argument of the `$location#search()` call must be a string or an object.

## Description

To resolve this error, ensure that the first argument for the `$location.search` call is a `string` or an object. You can use the stack trace associated with this error to identify the call site that caused this issue.

To learn more, please consult the `$location` api docs.